# @configu/py

## Install

```bash
pip install configu
```

## Usage
See example in the examples folder

## CONTRIBUTING

### Requirements

1. Follow the instructions on the main [CONTRIBUTING.md](https://github.com/configu/configu/blob/main/CONTRIBUTING.md)
   to set up node and npm. This is necessary for lint-staged workflow
2. Install [pyenv](https://github.com/pyenv/pyenv)
3. Install [poetry](https://python-poetry.org/)

### Setup

>  <span style="color:#FF392B">**Make sure you're in configu/py directory**</span>

#### Run these commands in order


```bash
pyenv install
```

```bash
pyenv local 3.9.16
```

```bash
poetry env use python
```

```bash
poetry install
```
